# Location Key Provisioning

## Description
This ceremony is for generating Location Keys. Location Keys are typically
stored in vaults as prescribed in the [Secure Storage Guidelines](secure-storage-guidelines.md).
Location Keys are keypairs to which the Root Entropy of a QKM is sharded. The
keypairs are stored exclusively on Smart Cards, and the PINs which protect the
Smart Cards are encrypted to Operator Keys.

## Requirements
* Smart Card(s): whatever number of smart cards you would like to have seeded
for each Operator, usually 2 per Operator is recommended - one NitroKey 3 and
1 YubiKey Series 5.

* [Storage Devices](equipment.md#storage-device): as many storage devices as you
would like for backing up [Public Ceremony Artifacts](public-ceremony-artifact-storage.md)

## Steps

1. Bring the Ceremony Machine and [Quorum Team](quorum-team.md) into the
established [Location](locations.md)

2. Boot your Ceremony Machine using [Secure Boot Sequence](secure-boot-sequence.md)
or the [One Time Use Airgap-OS](one-time-use-airgapos.md)

3. Provision new key in the selected secure environment

    * Load your personal PGP certificate which will be used as the Operator
    Key in to the local keyring

        * `gpg --import <your_key_id>`

    * Generate the mnemonic:

        * `keyfork mnemonic generate --size 256 > mnemonic.txt`

    * Encrypt the mnemonic to the Operator Key

        * `gpg -er <your_key_id> mnemonic.txt`

    * Save the encrypted mnemonic, `mnemonic.txt.gpg` to two SD cards

    * Print the contents of the mnemonic in a new terminal window as the seed
    phrase words need to be typed in during the following steps:

        * `cat mnemonic.txt`

    * In a new terminal window start `keyfork` daemon with the mnemonic:

        * `keyfork recover mnemonic`

    * Derive PGP keypair:

        * `keyfork derive openpgp "FirstName LastName (alias) <name@distrust.co>" > priv.asc`

    * Import PGP key into keyring

        * `gpg --import priv.asc`

    * Export PGP Public Certificate

        * `gpg --armor --export <key_id> > pub.asc`

    * Save `pub.asc` to two SD cards

    * Delete all the generated assets before shutting down computer, namely
    `pub.asc`, `priv.asc`, `mnemonic.txt` and `mnemonic.txt.gpg`

4. Follow the [Physical Artifact Storage](physical-artifact-storage.md) guide
 for storage of the Operator Smart Cards and Location Smart Cards

5. Follow the [Public Ceremony Artifacts Storage](public-ceremony-artifact-storage.md)
guide for all public artifacts produced during the ceremony
